Skip to contents

Restores the original scale of a normalized time series. The scale factor is retrieved from the "order" attribute of the input x, or optionally provided directly.

Usage

unit_denormalize(x, order = NULL)

Arguments

x

A normalized `ts` object.

order

Optional numeric. If provided, used as the scale factor.

Value

A `ts` object restored to its original scale.